.. meta::
    :description lang=en:
        Convert a long descriptive text into a text ad, by splitting it
        according to whichever template you want.

.. automodule:: advertools.ad_from_string
   :members:
   :undoc-members:
   :show-inheritance:
